==> org-lsst-ccs-subsystem-refrig-main-4.4.15-sources.jar: org/lsst/ccs/subsystem/refrig/ColdCompLimits.java <==
package org.lsst.ccs.subsystem.refrig;

import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.commons.annotations.ConfigurationParameterChanger;
import org.lsst.ccs.subsystem.refrig.constants.CompSwConds;

/**
 *  Manages refrigeration cold compressor limits.
 *
 *  @author Owen Saxton
 */
public class ColdCompLimits extends CompLimits {

    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true)
    private volatile int discPressDelayTime;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true)
    private volatile double liquidTempImmedLimit;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true)
    private volatile double liquidTempDelayLimit;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true)
    private volatile int liquidTempDelayTime;


    /**
     *  Sets the liquid temperature immediate limit.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempImmedLimit(double value)
    {
        liquidTempImmedLimit = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].immedLimit = value;
    }


    /**
     *  Sets the liquid temperature delayed limit.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempDelayLimit(double value)
    {
        liquidTempDelayLimit = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].delayLimit = value;
    }


    /**
     *  Sets the liquid temperature delay time.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempDelayTime(int value)
    {
        liquidTempDelayTime = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].delayTime = 1000 * value;
    }


    /**
     *  Sets the discharge pressure delay time.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setDiscPressDelayTime(int value)
    {
        discPressDelayTime = value;
        limitData[CompSwConds.SWC_DISC_PRESS].delayTime = 1000 * value;
    }

}

==> org-lsst-ccs-subsystem-refrig-main-4.4.28-20250324.194658-5-sources.jar: org/lsst/ccs/subsystem/refrig/ColdCompLimits.java <==
package org.lsst.ccs.subsystem.refrig;

import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.commons.annotations.ConfigurationParameterChanger;
import org.lsst.ccs.subsystem.refrig.constants.CompSwConds;

/**
 *  Manages refrigeration cold compressor limits.
 *
 *  @author Owen Saxton
 */
public class ColdCompLimits extends CompLimits {

    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true, units = "second", description = "Time delay before excess discharge pressure causes compressor shutoff")
    private volatile int discPressDelayTime;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true, units = "Celsius", description = "Liquid temperature limit causing immediate compressor shutoff")
    private volatile double liquidTempImmedLimit;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true, units = "Celsius", description = "Liquid temperature limit causing delayed compressor shutoff")
    private volatile double liquidTempDelayLimit;
    @ConfigurationParameter(category=COMP_LIMITS, isFinal=true, units = "second", description = "Time delay before excess liquid temperature causes compressor shutoff")
    private volatile int liquidTempDelayTime;


    /**
     *  Sets the liquid temperature immediate limit.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempImmedLimit(double value)
    {
        liquidTempImmedLimit = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].immedLimit = value;
    }


    /**
     *  Sets the liquid temperature delayed limit.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempDelayLimit(double value)
    {
        liquidTempDelayLimit = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].delayLimit = value;
    }


    /**
     *  Sets the liquid temperature delay time.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setLiquidTempDelayTime(int value)
    {
        liquidTempDelayTime = value;
        limitData[CompSwConds.SWC_LIQUID_TEMP].delayTime = 1000 * value;
    }


    /**
     *  Sets the discharge pressure delay time.
     *
     *  @param  value  The value to set
     */
    @ConfigurationParameterChanger
    public void setDiscPressDelayTime(int value)
    {
        discPressDelayTime = value;
        limitData[CompSwConds.SWC_DISC_PRESS].delayTime = 1000 * value;
    }

}
